@@ -135,13 +135,14 @@ classicthemerestorerjso.ctr = {
 		document.getElementById('ctraddon_pw_ib_nohovcolor').style.visibility = 'collapse';
 		document.getElementById('ctraddon_pw_altreaderico').style.visibility = 'collapse';
 	} else {
-		document.getElementById('ctraddon_pw_special_info2').style.visibility = 'collapse';
+		document.getElementById('ctraddon_pw_themes_note').style.visibility = 'collapse';
 		document.getElementById('ctraddon_pw_special_font').style.visibility = 'collapse';
 		document.getElementById('ctraddon_pw_tabforminfo').style.visibility = 'collapse';
 		document.getElementById('ctraddon_altoptions_list2').style.visibility = 'collapse';
+		document.getElementById('ctraddon_pw_dblclnewtabdes').style.visibility = 'collapse';
 	};
 
-	//ColorfulTabs info label
+	// ColorfulTabs info label
 	document.getElementById('ctraddon_coltabsinfo').style.visibility = 'collapse';
 
 	// radio restart label
@@ -160,6 +161,9 @@ classicthemerestorerjso.ctr = {
 	// 'Tabs on bottom' add-ons
 	document.getElementById('ctraddon_tobinfotab').style.visibility = 'collapse';
 	
+	// Add-on comaptibiliy reporter note
+	document.getElementById('ctraddon_pw_acr_note').style.visibility = 'collapse';
+	
 	// extra checks to not enable tab width settings while 'TabMixPlus' or 'TabUtilities' is enabled
 	AddonManager.getAddonByID('{dc572301-7619-498c-a57d-39143191b318}', function(addon) {
 	  if(addon && addon.isActive) {
@@ -345,6 +349,26 @@ classicthemerestorerjso.ctr = {
 	   }
 	};
 	AddonManager.addAddonListener(TOB2Listener);
+	
+	// 'Add-on comaptibiliy reporter' note
+	AddonManager.getAddonByID('compatibility@addons.mozilla.org', function(addon) {
+	  if(addon && addon.isActive) {
+		document.getElementById('ctraddon_pw_acr_note').style.visibility = 'visible';
+	  }
+	});
+	var ACRListener = {
+	   onEnabled: function(addon) {
+		  if(addon.id == 'compatibility@addons.mozilla.org') {
+			document.getElementById('ctraddon_pw_acr_note').style.visibility = 'visible';
+		  }
+	   },
+	   onDisabled: function(addon) {
+		  if(addon.id == 'compatibility@addons.mozilla.org') {
+			document.getElementById('ctraddon_pw_acr_note').style.visibility = 'collapse';
+		  }
+	   }
+	};
+	AddonManager.addAddonListener(ACRListener);
 
 	// disable bookmark animation checkbox, if 'star button in urlbar' is used
 	if (this.prefs.getBoolPref('starinurl')) document.getElementById('ctraddon_pw_bmanimation').disabled = true;
@@ -362,9 +386,10 @@ classicthemerestorerjso.ctr = {
 	if (this.appversion < 47) {
 	  document.getElementById('ctraddon_pw_hiderecentbm').style.visibility = 'collapse';
 	  document.getElementById('ctraddon_pw_hideeditbm').style.visibility = 'collapse';
+	  document.getElementById('ctraddon_pw_dblclnewtabdes').style.visibility = 'collapse';
 	}
 	
-	if (this.appversion >= 47 && Services.appinfo.OS=="Darwin") {
+	if (this.appversion >= 47/* && Services.appinfo.OS=="Darwin"*/) {
 	  document.getElementById('ctraddon_pw_hidetbwote').style.visibility = 'collapse';
 	}
 	
@@ -470,6 +495,32 @@ classicthemerestorerjso.ctr = {
 	
 	ctrSettingsListenerW_forCTR.register(true);
 	
+	
+	var ctrSettingsListenerW_forWTitlebar = new PrefListener(
+	  "browser.tabs.",
+	  function(branch, name) {
+		switch (name) {
+
+		  case "drawInTitlebar":
+		  
+		    if (classicthemerestorerjso.ctr.appversion >= 47 && branch.getBoolPref("drawInTitlebar")==false
+			  && (classicthemerestorerjso.ctr.fxdefaulttheme
+			    || Services.prefs.getBranch("lightweightThemes.")
+				  .getCharPref('selectedThemeID')=='firefox-devedition@mozilla.org')) {
+			  document.getElementById('ctraddon_pw_dblclnewtab').disabled = true;
+			  document.getElementById('ctraddon_pw_dblclnewtabdes').style.visibility = 'collapse';
+			} else {
+			  document.getElementById('ctraddon_pw_dblclnewtab').disabled = false;
+			}
+		  break;
+		}
+	  }
+	);
+	
+	// double click option is only available for Windows
+	if (this.oswindows)
+	  ctrSettingsListenerW_forWTitlebar.register(true);
+	
 	// update sub settings
 	this.ctrpwAppbuttonextra(this.prefs.getCharPref("appbutton"),false);
 	this.ctrpwAppbuttonColorExtra(this.prefs.getCharPref("appbuttonc"));
@@ -657,7 +708,7 @@ classicthemerestorerjso.ctr = {
 	  which=true; itemvis = 'collapse';
 	}
 	
-    if (this.appversion >= 47 && Services.appinfo.OS=="Darwin") {}
+    if (this.appversion >= 47 /*&& Services.appinfo.OS=="Darwin"*/) {}
 	else {
 	  document.getElementById('ctraddon_pw_hidetbwote').disabled = which;
 	  document.getElementById('ctraddon_pw_hidetbwote').style.visibility = itemvis;
@@ -821,7 +872,7 @@ classicthemerestorerjso.ctr = {
 	
     document.getElementById('ctraddon_pw_autocompl_it').disabled = which;
   },
- 
+
   ctrpwCtrOldSearch: function(which) {
 	var itemvis = 'collapse';
 	
